Boodler: The boodle-event.py Reference Manual

# Boodler: The `boodle-event.py` Reference Manual

The `boodle-event.py` script sends event messages to a listening Boodler process.

    boodle-event.py [--hostname host] [--port port] evname [ evdata ... ]

Some soundscapes can receive events, or messages, sent by other programs. The boodler.py script listens on a network socket for these messages if you give the `--listen` argument. (If you do not, Boodler does not listen for events, and event-receiving agents will not work. This is the default behavior for reasons of security paranoia.)

    boomsg.py go

This sends a simple message, `go`, to a listening Boodler process -- by default, on the same machine. To send a message to a different machine, you would say:

    boomsg.py --hostname machine.addr.net go

You can also send a more complex message, with several words:

    boomsg.py go 5.47 cheese

The effect of an event depends on what agent has been posted to receive it. For examples of soundscapes that receive events, see the `org.boodler.listen` package.

## Options

`--hostname host`
  Specify the machine to send the event to. By default, the event goes to the same machine that `boodle-event.py` runs on.
`--port port/pipe`
  Send to the given port number (instead of the default port 31863). The port may also be an absolute pathname (beginning with "/"), in which case Boodler uses a Unix domain socket (on the same machine) instead of a network socket.

Return to Boodler docs index